package com.aucma.report.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * PDA管理Service接口
 * 
 * @author Yinq
 * @date 2023-11-21
 */
public interface IQualityReportService
{


    /**
     * 质量缺陷统计分析
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> qualityDefectsStatisticalAnalysisList(Map hashMap);

    /**
     * 少错件报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> fewerMistakesReportList(Map hashMap);

    /**
     * 质量问题前80报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> qualityIssuesReportList(Map hashMap);

    /**
     * 产品追溯报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> productTraceabilityReportList(Map hashMap);

    /**
     * 测温记录报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> temperatureRecordReportList(Map hashMap);

    /**
     * 灌注记录报表
     * @param hashMap
     * @return
     */
    List<HashMap<String, Object>> pourRecordReportList(Map hashMap);
}
